==> nomachine-8.14.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXLoadBalance.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2024 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub NXLoadBalance::initRedis{package NXLoadBalance;no warnings;Logger::debug (
"\x6c\x69\x62\x6e\x78\x68\x73\x3a\x3a\x4e\x58\x53\x75\x62\x73\x79\x73\x74\x65\x6d\x47\x65\x74\x52\x65\x64\x69\x73\x46\x64\x28\x29"
);(my $FD=libnxhs::NXSubsystemGetRedisFd ());Logger::debug2 (((
"\x6c\x69\x62\x6e\x78\x68\x73\x3a\x3a\x4e\x58\x53\x75\x62\x73\x79\x73\x74\x65\x6d\x47\x65\x74\x52\x65\x64\x69\x73\x46\x64\x28\x29\x20\x72\x65\x74\x75\x72\x6e\x73\x20\x27"
.$FD)."\x27\x2e"));if (($FD>=(0x06b1+ 1944-0x0e49))){($NXRedis::connected=
(0x1ed0+ 819-0x2202));($NXRedis::readRedis=$FD);Logger::debug (((
"\x4e\x58\x4c\x6f\x61\x64\x42\x61\x6c\x61\x6e\x63\x65\x3a\x20\x52\x65\x64\x69\x73\x20\x63\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x20\x69\x6e\x68\x65\x72\x69\x74\x65\x64\x20\x46\x44\x23"
.$FD)."\x2e"));($NXRedis::selector=
"\x43\x6f\x6d\x6d\x6f\x6e\x3a\x3a\x4e\x58\x53\x65\x6c\x65\x63\x74\x6f\x72"->new)
;$NXRedis::selector->add ($NXRedis::readRedis);$NXRedis::selector->add (
$$NXBegin::parser{"\x53\x69\x67\x6e\x61\x6c"});}else{Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x72\x65\x74\x72\x69\x65\x76\x65\x20\x52\x65\x64\x69\x73\x20\x63\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x2e"
);}main::nxrequire ("\x4e\x58\x52\x65\x64\x69\x73");if (
NXRedis::checkIfSubscriptionShouldBeStarted ()){Logger::debug (
"\x6c\x69\x62\x6e\x78\x68\x73\x3a\x3a\x4e\x58\x53\x75\x62\x73\x79\x73\x74\x65\x6d\x47\x65\x74\x52\x65\x64\x69\x73\x53\x75\x62\x73\x46\x64\x28\x29"
);(my $FD=libnxhs::NXSubsystemGetRedisSubsFd ());Logger::debug2 (((
"\x6c\x69\x62\x6e\x78\x68\x73\x3a\x3a\x4e\x58\x53\x75\x62\x73\x79\x73\x74\x65\x6d\x47\x65\x74\x52\x65\x64\x69\x73\x53\x75\x62\x73\x46\x64\x20\x72\x65\x74\x75\x72\x6e\x73\x20\x27"
.$FD)."\x27\x2e"));if (($FD>=(0x12e8+ 3546-0x20c2))){main::nxrequire (
"\x4e\x58\x52\x65\x64\x69\x73\x53\x75\x62\x73\x63\x72\x69\x70\x74\x69\x6f\x6e");
NXRedisSubscription::setSubscriptionConnected ();
NXRedisSubscription::setSubscriptionClientOutputSocket ($FD);
Common::NXSelector::addToGlobalSelector ($FD,
"\x72\x65\x64\x69\x73\x20\x73\x75\x62\x73\x63\x72\x69\x70\x74\x69\x6f\x6e\x20\x73\x6f\x63\x6b\x65\x74"
,
"\x4e\x58\x52\x65\x64\x69\x73\x53\x75\x62\x73\x63\x72\x69\x70\x74\x69\x6f\x6e\x3a\x3a\x73\x75\x62\x73\x63\x72\x69\x70\x74\x69\x6f\x6e\x50\x61\x72\x73\x65\x72"
);}else{Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x72\x65\x74\x72\x69\x65\x76\x65\x20\x52\x65\x64\x69\x73\x20\x73\x75\x62\x73\x63\x72\x69\x70\x74\x69\x6f\x6e\x2e"
);}}}package NXLoadBalance;no warnings;return ((0x16c4+ 2631-0x210a));

==> nomachine-8.16.1-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXLoadBalance.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2025 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub NXLoadBalance::initRedis{package NXLoadBalance;no warnings;Logger::debug (
"\x6c\x69\x62\x6e\x78\x68\x73\x3a\x3a\x4e\x58\x53\x75\x62\x73\x79\x73\x74\x65\x6d\x47\x65\x74\x52\x65\x64\x69\x73\x46\x64\x28\x29"
);(my $FD=libnxhs::NXSubsystemGetRedisFd ());Logger::debug2 (((
"\x6c\x69\x62\x6e\x78\x68\x73\x3a\x3a\x4e\x58\x53\x75\x62\x73\x79\x73\x74\x65\x6d\x47\x65\x74\x52\x65\x64\x69\x73\x46\x64\x28\x29\x20\x72\x65\x74\x75\x72\x6e\x73\x20\x27"
.$FD)."\x27\x2e"));if (($FD>=(0x01c7+ 6626-0x1ba9))){($NXRedis::connected=
(0x0eaf+ 4385-0x1fcf));($NXRedis::readRedis=$FD);Logger::debug (((
"\x4e\x58\x4c\x6f\x61\x64\x42\x61\x6c\x61\x6e\x63\x65\x3a\x20\x52\x65\x64\x69\x73\x20\x63\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x20\x69\x6e\x68\x65\x72\x69\x74\x65\x64\x20\x46\x44\x23"
.$FD)."\x2e"));($NXRedis::selector=
"\x43\x6f\x6d\x6d\x6f\x6e\x3a\x3a\x4e\x58\x53\x65\x6c\x65\x63\x74\x6f\x72"->new)
;$NXRedis::selector->add ($NXRedis::readRedis);$NXRedis::selector->add (
$$NXBegin::parser{"\x53\x69\x67\x6e\x61\x6c"});}else{Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x72\x65\x74\x72\x69\x65\x76\x65\x20\x52\x65\x64\x69\x73\x20\x63\x6f\x6e\x6e\x65\x63\x74\x69\x6f\x6e\x2e"
);}main::nxrequire ("\x4e\x58\x52\x65\x64\x69\x73");if (
NXRedis::checkIfSubscriptionShouldBeStarted ()){Logger::debug (
"\x6c\x69\x62\x6e\x78\x68\x73\x3a\x3a\x4e\x58\x53\x75\x62\x73\x79\x73\x74\x65\x6d\x47\x65\x74\x52\x65\x64\x69\x73\x53\x75\x62\x73\x46\x64\x28\x29"
);(my $FD=libnxhs::NXSubsystemGetRedisSubsFd ());Logger::debug2 (((
"\x6c\x69\x62\x6e\x78\x68\x73\x3a\x3a\x4e\x58\x53\x75\x62\x73\x79\x73\x74\x65\x6d\x47\x65\x74\x52\x65\x64\x69\x73\x53\x75\x62\x73\x46\x64\x20\x72\x65\x74\x75\x72\x6e\x73\x20\x27"
.$FD)."\x27\x2e"));if (($FD>=(0x1cd5+ 2479-0x2684))){main::nxrequire (
"\x4e\x58\x52\x65\x64\x69\x73\x53\x75\x62\x73\x63\x72\x69\x70\x74\x69\x6f\x6e");
NXRedisSubscription::setSubscriptionConnected ();
NXRedisSubscription::setSubscriptionClientOutputSocket ($FD);
Common::NXSelector::addToGlobalSelector ($FD,
"\x72\x65\x64\x69\x73\x20\x73\x75\x62\x73\x63\x72\x69\x70\x74\x69\x6f\x6e\x20\x73\x6f\x63\x6b\x65\x74"
,
"\x4e\x58\x52\x65\x64\x69\x73\x53\x75\x62\x73\x63\x72\x69\x70\x74\x69\x6f\x6e\x3a\x3a\x73\x75\x62\x73\x63\x72\x69\x70\x74\x69\x6f\x6e\x50\x61\x72\x73\x65\x72"
);}else{Logger::warning (
"\x43\x61\x6e\x6e\x6f\x74\x20\x72\x65\x74\x72\x69\x65\x76\x65\x20\x52\x65\x64\x69\x73\x20\x73\x75\x62\x73\x63\x72\x69\x70\x74\x69\x6f\x6e\x2e"
);}}}package NXLoadBalance;no warnings;return ((0x0008+ 4100-0x100b));
